get.nindi: Number of individuals
Description
Function to calculate the number of individuals in the population list
Usage
get.nindi(
population,
database = NULL,
gen = NULL,
cohorts = NULL,
id = NULL,
extended = FALSE,
count.copy = FALSE
)
Arguments
- population
Population list
- database
Groups of individuals to consider for the export
- gen
Quick-insert for database (vector of all generations to export)
- cohorts
Quick-insert for database (vector of names of cohorts to export)
- id
Individual IDs to search/collect in the database
- extended
Set to TRUE to export information on number of phenotyped, genotyped, and both pheno&genotyped individuals
- count.copy
Set to TRUE to double count individuals if multiple copies of an individual are included in gen/database/cohorts
Examples
Run this codedata(ex_pop)
get.nindi(ex_pop, gen = 1)
Run the code above in your browser using DataLab