Function to derive snapshot of genotyping/phenotyping state of selected individuals
get.snapshot.single(
population,
database = NULL,
gen = NULL,
cohorts = NULL,
id = NULL,
phenotype.data = FALSE,
gain.data = FALSE,
digits = 3,
time.diff = 1,
min.time = -Inf,
max.time = Inf,
use.all.copy = TRUE,
verbose = TRUE,
time.points = NULL,
include.culled = FALSE
)Snapshot Matrix
Population list
Groups of individuals to consider for the export
Quick-insert for database (vector of all generations to export)
Quick-insert for database (vector of names of cohorts to export)
Individual IDs to search/collect in the database
Set to TRUE to include information of number of phenotypes generated
Set to TRUE to add information on changes in genetic level between cohorts (default: FALSE)
Number of digits provided for the gain.data output (default: 3)
Set to a target time interval to receive information between transitions to other cohorts (default: NA)
Earliest time point relevant for output results (default: -Inf)
Latest time point relevant for output results (default: Inf)
Set to TRUE to extract phenotyping
Set to FALSE to not display any prints (default: TRUE)
Use this parameter to manual provide a vector of time points on results should be generated for (default: NULL)
Set to TRUE to also include culled individuals in the statistics provided
data(ex_pop)
get.snapshot.single(ex_pop, cohorts = "Cohort_2_M")
Run the code above in your browser using DataLab