recalculate.bv: Recalculate genomic values
Description
Function to recalculate genomic values
Usage
recalculate.bv(
population,
gen = NULL,
database = NULL,
cohorts = NULL,
bv.ignore.traits = NULL,
store.comp.times = TRUE
)
Arguments
- population
Population list
- gen
Quick-insert for database (vector of all generations to export)
- database
Groups of individuals to consider for the export
- cohorts
Quick-insert for database (vector of names of cohorts to export)
- bv.ignore.traits
Vector of traits to ignore in the calculation of the genomic value (default: NULL; Only recommended for high number of traits and experienced users!)
- store.comp.times
If TRUE store computation times in $info$comp.times.general (default: TRUE)
Examples
Run this codedata(ex_pop)
population <- recalculate.bv(ex_pop, gen=2)
Run the code above in your browser using DataLab